@@ -12,15 +12,15 @@ class Tokenize(object):
                  unk_token='<unk>') -> None:
         super().__init__()
 
-        abs_direct = 'genz_tokenize/data/'
+        this_dir, this_filename = os.path.split(__file__)
         try:
             self.vocab_file
         except:
-            self.vocab_file = abs_direct + 'vocab.txt'
+            self.vocab_file = os.path.join(this_dir, 'data', 'vocab.txt')
         try:
             self.bpe_file
         except:
-            self.bpe_file = abs_direct + 'bpe.codes'
+            self.bpe_file = os.path.join(this_dir, 'data', 'bpe.codes')
 
         self.pad_token = pad_token
         self.bos_token = bos_token
